@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -55,13 +55,13 @@
 //
 
 /** The continue 100 status code http model. */
-static char CONTINUE_100_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '0', ' ', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'e'};
-static char* CONTINUE_100_STATUS_CODE_HTTP_MODEL = CONTINUE_100_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char CONTINUE_100_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '0', ' ', 'C', 'o', 'n', 't', 'i', 'n', 'u', 'e'};
+static unsigned char* CONTINUE_100_STATUS_CODE_HTTP_MODEL = CONTINUE_100_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* CONTINUE_100_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_12_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The switching protocols 101 status code http model. */
-static char SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '1', ' ', 'S', 'w', 'i', 't', 'c', 'h', 'i', 'n', 'g', ' ', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's'};
-static char* SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL = SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '1', ' ', 'S', 'w', 'i', 't', 'c', 'h', 'i', 'n', 'g', ' ', 'P', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's'};
+static unsigned char* SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL = SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_23_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -71,8 +71,8 @@ static int* SWITCHING_PROTOCOLS_101_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_23_INT
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char PROCESSING_102_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '2', ' ', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g'};
-static char* PROCESSING_102_STATUS_CODE_HTTP_MODEL = PROCESSING_102_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char PROCESSING_102_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'1', '0', '2', ' ', 'P', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g'};
+static unsigned char* PROCESSING_102_STATUS_CODE_HTTP_MODEL = PROCESSING_102_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* PROCESSING_102_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_14_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -84,38 +84,38 @@ static int* PROCESSING_102_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_14_INTEGER_STAT
 //
 
 /** The ok 200 status code http model. */
-static char OK_200_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '0', ' ', 'O', 'K'};
-static char* OK_200_STATUS_CODE_HTTP_MODEL = OK_200_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char OK_200_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '0', ' ', 'O', 'K'};
+static unsigned char* OK_200_STATUS_CODE_HTTP_MODEL = OK_200_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* OK_200_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_6_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The created 201 status code http model. */
-static char CREATED_201_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '1', ' ', 'C', 'r', 'e', 'a', 't', 'e', 'd'};
-static char* CREATED_201_STATUS_CODE_HTTP_MODEL = CREATED_201_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char CREATED_201_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '1', ' ', 'C', 'r', 'e', 'a', 't', 'e', 'd'};
+static unsigned char* CREATED_201_STATUS_CODE_HTTP_MODEL = CREATED_201_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* CREATED_201_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The accepted 202 status code http model. */
-static char ACCEPTED_202_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '2', ' ', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd'};
-static char* ACCEPTED_202_STATUS_CODE_HTTP_MODEL = ACCEPTED_202_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char ACCEPTED_202_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '2', ' ', 'A', 'c', 'c', 'e', 'p', 't', 'e', 'd'};
+static unsigned char* ACCEPTED_202_STATUS_CODE_HTTP_MODEL = ACCEPTED_202_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* ACCEPTED_202_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_12_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The non-authoritative information 203 status code http model. */
-static char NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '3', ' ', 'N', 'o', 'n', '-', 'A', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 't', 'i', 'v', 'e', ' ', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n'};
-static char* NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL = NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '3', ' ', 'N', 'o', 'n', '-', 'A', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 't', 'i', 'v', 'e', ' ', 'I', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n'};
+static unsigned char* NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL = NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NON_AUTHORITATIVE_203_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_33_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The no content 204 status code http model. */
-static char NO_CONTENT_204_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '4', ' ', 'N', 'o', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
-static char* NO_CONTENT_204_STATUS_CODE_HTTP_MODEL = NO_CONTENT_204_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NO_CONTENT_204_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '4', ' ', 'N', 'o', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
+static unsigned char* NO_CONTENT_204_STATUS_CODE_HTTP_MODEL = NO_CONTENT_204_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NO_CONTENT_204_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_14_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The reset content 205 status code http model. */
-static char RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '5', ' ', 'R', 'e', 's', 'e', 't', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
-static char* RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL = RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '5', ' ', 'R', 'e', 's', 'e', 't', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
+static unsigned char* RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL = RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* RESET_CONTENT_205_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_17_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The partial content 206 status code http model. */
-static char PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '6', ' ', 'P', 'a', 'r', 't', 'i', 'a', 'l', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
-static char* PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL = PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '6', ' ', 'P', 'a', 'r', 't', 'i', 'a', 'l', ' ', 'C', 'o', 'n', 't', 'e', 'n', 't'};
+static unsigned char* PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL = PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -125,8 +125,8 @@ static int* PARTIAL_CONTENT_206_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '7', ' ', 'M', 'u', 'l', 't', 'i', '-', 'S', 't', 'a', 't', 'u', 's'};
-static char* MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL = MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'2', '0', '7', ' ', 'M', 'u', 'l', 't', 'i', '-', 'S', 't', 'a', 't', 'u', 's'};
+static unsigned char* MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL = MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_16_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -145,33 +145,33 @@ static int* MULTI_STATUS_207_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_16_INTEGER_ST
 //
 
 /** The multiple choices 300 status code http model. */
-static char MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '0', ' ', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', ' ', 'C', 'h', 'o', 'i', 'c', 'e', 's'};
-static char* MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL = MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '0', ' ', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'e', ' ', 'C', 'h', 'o', 'i', 'c', 'e', 's'};
+static unsigned char* MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL = MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* MULTIPLE_CHOICES_300_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_20_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The moved permanently 301 status code http model. */
-static char MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '1', ' ', 'M', 'o', 'v', 'e', 'd', ' ', 'P', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', 'l', 'y'};
-static char* MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL = MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '1', ' ', 'M', 'o', 'v', 'e', 'd', ' ', 'P', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', 'l', 'y'};
+static unsigned char* MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL = MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* MOVED_PERMANENTLY_301_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_21_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The found 302 status code http model. */
-static char FOUND_302_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '2', ' ', 'F', 'o', 'u', 'n', 'd'};
-static char* FOUND_302_STATUS_CODE_HTTP_MODEL = FOUND_302_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char FOUND_302_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '2', ' ', 'F', 'o', 'u', 'n', 'd'};
+static unsigned char* FOUND_302_STATUS_CODE_HTTP_MODEL = FOUND_302_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* FOUND_302_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The see other 303 status code http model. */
-static char SEE_OTHER_303_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '3', ' ', 'S', 'e', 'e', ' ', 'O', 't', 'h', 'e', 'r'};
-static char* SEE_OTHER_303_STATUS_CODE_HTTP_MODEL = SEE_OTHER_303_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char SEE_OTHER_303_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '3', ' ', 'S', 'e', 'e', ' ', 'O', 't', 'h', 'e', 'r'};
+static unsigned char* SEE_OTHER_303_STATUS_CODE_HTTP_MODEL = SEE_OTHER_303_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* SEE_OTHER_303_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_13_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The not modified 304 status code http model. */
-static char NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '4', ' ', 'N', 'o', 't', ' ', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd'};
-static char* NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL = NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '4', ' ', 'N', 'o', 't', ' ', 'M', 'o', 'd', 'i', 'f', 'i', 'e', 'd'};
+static unsigned char* NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL = NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NOT_MODIFIED_304_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_16_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The use proxy 305 status code http model. */
-static char USE_PROXY_305_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '5', ' ', 'U', 's', 'e', ' ', 'P', 'r', 'o', 'x', 'y'};
-static char* USE_PROXY_305_STATUS_CODE_HTTP_MODEL = USE_PROXY_305_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char USE_PROXY_305_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '5', ' ', 'U', 's', 'e', ' ', 'P', 'r', 'o', 'x', 'y'};
+static unsigned char* USE_PROXY_305_STATUS_CODE_HTTP_MODEL = USE_PROXY_305_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* USE_PROXY_305_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_13_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -181,14 +181,14 @@ static int* USE_PROXY_305_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_13_INTEGER_STATE
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '6', ' ', 'S', 'w', 'i', 't', 'c', 'h', ' ', 'P', 'r', 'o', 'x', 'y'};
-static char* SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL = SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '6', ' ', 'S', 'w', 'i', 't', 'c', 'h', ' ', 'P', 'r', 'o', 'x', 'y'};
+static unsigned char* SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL = SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* SWITCH_PROXY_306_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_16_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
 /** The temporary redirect (moved temporarily) 307 status code http model. */
-static char TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '7', ' ', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', ' ', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't'};
-static char* TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL = TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'3', '0', '7', ' ', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', ' ', 'R', 'e', 'd', 'i', 'r', 'e', 'c', 't'};
+static unsigned char* TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL = TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_22_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 //
@@ -209,93 +209,93 @@ static int* TEMPORARY_REDIRECT_307_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_22_INTE
 //
 
 /** The bad request 400 status code http model. */
-static char BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '0', ' ', 'B', 'a', 'd', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't'};
-static char* BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL = BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '0', ' ', 'B', 'a', 'd', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't'};
+static unsigned char* BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL = BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* BAD_REQUEST_400_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_15_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The unauthorized 401 status code http model. */
-static char UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '1', ' ', 'U', 'n', 'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'd'};
-static char* UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL = UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '1', ' ', 'U', 'n', 'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'd'};
+static unsigned char* UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL = UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* UNAUTHORIZED_401_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_16_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The payment required 402 status code http model. */
-static char PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '2', ' ', 'P', 'a', 'y', 'm', 'e', 'n', 't', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
-static char* PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL = PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '2', ' ', 'P', 'a', 'y', 'm', 'e', 'n', 't', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
+static unsigned char* PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL = PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* PAYMENT_REQUIRED_402_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_20_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The forbidden 403 status code http model. */
-static char FORBIDDEN_403_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '3', ' ', 'F', 'o', 'r', 'b', 'i', 'd', 'd', 'e', 'n'};
-static char* FORBIDDEN_403_STATUS_CODE_HTTP_MODEL = FORBIDDEN_403_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char FORBIDDEN_403_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '3', ' ', 'F', 'o', 'r', 'b', 'i', 'd', 'd', 'e', 'n'};
+static unsigned char* FORBIDDEN_403_STATUS_CODE_HTTP_MODEL = FORBIDDEN_403_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* FORBIDDEN_403_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_13_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The not found 404 status code http model. */
-static char NOT_FOUND_404_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '4', ' ', 'N', 'o', 't', ' ', 'F', 'o', 'u', 'n', 'd'};
-static char* NOT_FOUND_404_STATUS_CODE_HTTP_MODEL = NOT_FOUND_404_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NOT_FOUND_404_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '4', ' ', 'N', 'o', 't', ' ', 'F', 'o', 'u', 'n', 'd'};
+static unsigned char* NOT_FOUND_404_STATUS_CODE_HTTP_MODEL = NOT_FOUND_404_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NOT_FOUND_404_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_13_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The method not allowed 405 status code http model. */
-static char METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '5', ' ', 'M', 'e', 't', 'h', 'o', 'd', ' ', 'N', 'o', 't', ' ', 'A', 'l', 'l', 'o', 'w', 'e', 'd'};
-static char* METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL = METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '5', ' ', 'M', 'e', 't', 'h', 'o', 'd', ' ', 'N', 'o', 't', ' ', 'A', 'l', 'l', 'o', 'w', 'e', 'd'};
+static unsigned char* METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL = METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* METHOD_NOT_ALLOWED_405_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_22_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The not acceptable 406 status code http model. */
-static char NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '6', ' ', 'N', 'o', 't', ' ', 'A', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e'};
-static char* NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL = NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '6', ' ', 'N', 'o', 't', ' ', 'A', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e'};
+static unsigned char* NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL = NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NOT_ACCEPTABLE_406_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_18_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The proxy authentication required 407 status code http model. */
-static char PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '7', ' ', 'P', 'r', 'o', 'x', 'y', ' ', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
-static char* PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL = PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '7', ' ', 'P', 'r', 'o', 'x', 'y', ' ', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
+static unsigned char* PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL = PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* PROXY_AUTHENTICATION_REQUIRED_407_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_33_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The request timeout 408 status code http model. */
-static char REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '8', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', ' ', 'T', 'i', 'm', 'e', 'o', 'u', 't'};
-static char* REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL = REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '8', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', ' ', 'T', 'i', 'm', 'e', 'o', 'u', 't'};
+static unsigned char* REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL = REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* REQUEST_TIMEOUT_408_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The conflict 409 status code http model. */
-static char CONFLICT_409_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '9', ' ', 'C', 'o', 'n', 'f', 'l', 'i', 'c', 't'};
-static char* CONFLICT_409_STATUS_CODE_HTTP_MODEL = CONFLICT_409_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char CONFLICT_409_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '0', '9', ' ', 'C', 'o', 'n', 'f', 'l', 'i', 'c', 't'};
+static unsigned char* CONFLICT_409_STATUS_CODE_HTTP_MODEL = CONFLICT_409_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* CONFLICT_409_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_12_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The gone 410 status code http model. */
-static char GONE_410_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '0', ' ', 'G', 'o', 'n', 'e'};
-static char* GONE_410_STATUS_CODE_HTTP_MODEL = GONE_410_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char GONE_410_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '0', ' ', 'G', 'o', 'n', 'e'};
+static unsigned char* GONE_410_STATUS_CODE_HTTP_MODEL = GONE_410_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* GONE_410_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_8_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The length required 411 status code http model. */
-static char LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '1', ' ', 'L', 'e', 'n', 'g', 't', 'h', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
-static char* LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL = LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '1', ' ', 'L', 'e', 'n', 'g', 't', 'h', ' ', 'R', 'e', 'q', 'u', 'i', 'r', 'e', 'd'};
+static unsigned char* LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL = LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* LENGTH_REQUIRED_411_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The precondition failed 412 status code http model. */
-static char PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '2', ' ', 'P', 'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', ' ', 'F', 'a', 'i', 'l', 'e', 'd'};
-static char* PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL = PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '2', ' ', 'P', 'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', ' ', 'F', 'a', 'i', 'l', 'e', 'd'};
+static unsigned char* PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL = PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* PRECONDITION_FAILED_412_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_23_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The request entity too large 413 status code http model. */
-static char REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '3', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', ' ', 'E', 'n', 't', 'i', 't', 'y', ' ', 'T', 'o', 'o', ' ', 'L', 'a', 'r', 'g', 'e'};
-static char* REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL = REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '3', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', ' ', 'E', 'n', 't', 'i', 't', 'y', ' ', 'T', 'o', 'o', ' ', 'L', 'a', 'r', 'g', 'e'};
+static unsigned char* REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL = REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* REQUEST_ENTITY_TOO_LARGE_413_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_28_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The request-uri too long 414 status code http model. */
-static char REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '4', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', '-', 'U', 'R', 'I', ' ', 'T', 'o', 'o', ' ', 'L', 'o', 'n', 'g'};
-static char* REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL = REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '4', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', '-', 'U', 'R', 'I', ' ', 'T', 'o', 'o', ' ', 'L', 'o', 'n', 'g'};
+static unsigned char* REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL = REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* REQUEST_URI_TOO_LARGE_414_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_24_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The unsupported media type 415 status code http model. */
-static char UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '5', ' ', 'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', ' ', 'M', 'e', 'd', 'i', 'a', ' ', 'T', 'y', 'p', 'e'};
-static char* UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL = UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '5', ' ', 'U', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', ' ', 'M', 'e', 'd', 'i', 'a', ' ', 'T', 'y', 'p', 'e'};
+static unsigned char* UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL = UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* UNSUPPORTED_MEDIA_TYPE_415_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_26_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The requested range not satisfiable 416 status code http model. */
-static char REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '6', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', ' ', 'R', 'a', 'n', 'g', 'e', ' ', 'N', 'o', 't', ' ', 'S', 'a', 't', 'i', 's', 'f', 'i', 'a', 'b', 'l', 'e'};
-static char* REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL = REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '6', ' ', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', ' ', 'R', 'a', 'n', 'g', 'e', ' ', 'N', 'o', 't', ' ', 'S', 'a', 't', 'i', 's', 'f', 'i', 'a', 'b', 'l', 'e'};
+static unsigned char* REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL = REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* REQUESTED_RANGE_NOT_SATISFIABLE_416_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_35_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The expectation failed 417 status code http model. */
-static char EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '7', ' ', 'E', 'x', 'p', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', ' ', 'F', 'a', 'i', 'l', 'e', 'd'};
-static char* EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL = EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '1', '7', ' ', 'E', 'x', 'p', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', ' ', 'F', 'a', 'i', 'l', 'e', 'd'};
+static unsigned char* EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL = EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_22_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -305,8 +305,8 @@ static int* EXPECTATION_FAILED_417_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_22_INTE
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '2', ' ', 'U', 'n', 'p', 'r', 'o', 'c', 'e', 's', 's', 'a', 'b', 'l', 'e', ' ', 'E', 'n', 't', 'i', 't', 'y'};
-static char* UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL = UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '2', ' ', 'U', 'n', 'p', 'r', 'o', 'c', 'e', 's', 's', 'a', 'b', 'l', 'e', ' ', 'E', 'n', 't', 'i', 't', 'y'};
+static unsigned char* UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL = UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_24_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -317,8 +317,8 @@ static int* UNPROCESSABLE_ENTITY_422_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_24_IN
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char LOCKED_423_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '3', ' ', 'L', 'o', 'c', 'k', 'e', 'd'};
-static char* LOCKED_423_STATUS_CODE_HTTP_MODEL = LOCKED_423_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char LOCKED_423_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '3', ' ', 'L', 'o', 'c', 'k', 'e', 'd'};
+static unsigned char* LOCKED_423_STATUS_CODE_HTTP_MODEL = LOCKED_423_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* LOCKED_423_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -329,8 +329,8 @@ static int* LOCKED_423_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_10_INTEGER_STATE_CY
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '4', ' ', 'F', 'a', 'i', 'l', 'e', 'd', ' ', 'D', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'y'};
-static char* FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL = FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'4', '2', '4', ' ', 'F', 'a', 'i', 'l', 'e', 'd', ' ', 'D', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'y'};
+static unsigned char* FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL = FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_21_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -345,33 +345,33 @@ static int* FAILED_DEPENDENCY_424_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_21_INTEG
 //
 
 /** The internal server error 500 status code http model. */
-static char INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '0', ' ', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', ' ', 'S', 'e', 'r', 'v', 'e', 'r', ' ', 'E', 'r', 'r', 'o', 'r'};
-static char* INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL = INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '0', ' ', 'I', 'n', 't', 'e', 'r', 'n', 'a', 'l', ' ', 'S', 'e', 'r', 'v', 'e', 'r', ' ', 'E', 'r', 'r', 'o', 'r'};
+static unsigned char* INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL = INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* INTERNAL_SERVER_ERROR_500_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_25_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The not implemented 501 status code http model. */
-static char NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '1', ' ', 'N', 'o', 't', ' ', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd'};
-static char* NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL = NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '1', ' ', 'N', 'o', 't', ' ', 'I', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd'};
+static unsigned char* NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL = NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* NOT_IMPLEMENTED_501_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The bad gateway 502 status code http model. */
-static char BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '2', ' ', 'B', 'a', 'd', ' ', 'G', 'a', 't', 'e', 'w', 'a', 'y'};
-static char* BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL = BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '2', ' ', 'B', 'a', 'd', ' ', 'G', 'a', 't', 'e', 'w', 'a', 'y'};
+static unsigned char* BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL = BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* BAD_GATEWAY_502_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_15_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The service unavailable 503 status code http model. */
-static char SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '3', ' ', 'S', 'e', 'r', 'v', 'i', 'c', 'e', ' ', 'U', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e'};
-static char* SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL = SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '3', ' ', 'S', 'e', 'r', 'v', 'i', 'c', 'e', ' ', 'U', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e'};
+static unsigned char* SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL = SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* SERVICE_UNAVAILABLE_503_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_23_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The gateway timeout 504 status code http model. */
-static char GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '4', ' ', 'G', 'a', 't', 'e', 'w', 'a', 'y', ' ', 'T', 'i', 'm', 'e', 'o', 'u', 't'};
-static char* GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL = GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '4', ' ', 'G', 'a', 't', 'e', 'w', 'a', 'y', ' ', 'T', 'i', 'm', 'e', 'o', 'u', 't'};
+static unsigned char* GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL = GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* GATEWAY_TIMEOUT_504_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_19_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /** The http version not supported 505 status code http model. */
-static char HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '5', ' ', 'H', 'T', 'T', 'P', ' ', 'V', 'e', 'r', 's', 'i', 'o', 'n', ' ', 'N', 'o', 't', ' ', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd'};
-static char* HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL = HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '5', ' ', 'H', 'T', 'T', 'P', ' ', 'V', 'e', 'r', 's', 'i', 'o', 'n', ' ', 'N', 'o', 't', ' ', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd'};
+static unsigned char* HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL = HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_30_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /**
@@ -381,8 +381,8 @@ static int* HTTP_VERSION_NOT_SUPPORTED_505_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '7', ' ', 'I', 'n', 's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', ' ', 'S', 't', 'o', 'r', 'a', 'g', 'e'};
-static char* INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL = INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '7', ' ', 'I', 'n', 's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', ' ', 'S', 't', 'o', 'r', 'a', 'g', 'e'};
+static unsigned char* INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL = INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_24_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
@@ -393,8 +393,8 @@ static int* INSUFFICIENT_STORAGE_507_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_24_IN
  * http://www.w3.org/Protocols/HTTP/1.1/rfc2616bis/draft-lafon-rfc2616bis-03.html
  */
 /*??
-static char BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '9', ' ', 'B', 'a', 'n', 'd', 'w', 'i', 'd', 't', 'h', ' ', 'L', 'i', 'm', 'i', 't', ' ', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd'};
-static char* BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL = BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL_ARRAY;
+static unsigned char BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL_ARRAY[] = {'5', '0', '9', ' ', 'B', 'a', 'n', 'd', 'w', 'i', 'd', 't', 'h', ' ', 'L', 'i', 'm', 'i', 't', ' ', 'E', 'x', 'c', 'e', 'e', 'd', 'e', 'd'};
+static unsigned char* BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL = BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL_ARRAY;
 static int* BANDWIDTH_LIMIT_EXCEEDED_509_STATUS_CODE_HTTP_MODEL_COUNT = NUMBER_28_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 */
 
