@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,11 +27,12 @@
 #define VARIABLE_HTTP_NAME_CONSTANT_SOURCE
 
 #include <stddef.h>
+
 #include "../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 
 /** The Charset variable http name. */
-static char CHARSET_VARIABLE_HTTP_NAME_ARRAY[] = {'C', 'h', 'a', 'r', 's', 'e', 't'};
-static char* CHARSET_VARIABLE_HTTP_NAME = CHARSET_VARIABLE_HTTP_NAME_ARRAY;
+static unsigned char CHARSET_VARIABLE_HTTP_NAME_ARRAY[] = {'C', 'h', 'a', 'r', 's', 'e', 't'};
+static unsigned char* CHARSET_VARIABLE_HTTP_NAME = CHARSET_VARIABLE_HTTP_NAME_ARRAY;
 static int* CHARSET_VARIABLE_HTTP_NAME_COUNT = NUMBER_7_INTEGER_STATE_CYBOI_MODEL_ARRAY;
 
 /* VARIABLE_HTTP_NAME_CONSTANT_SOURCE */
