@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -27,12 +27,12 @@
 #define INITIALISER_SOURCE
 
 #include "../constant/encoding/cyboi/cyboi_encoding.c"
+#include "../constant/format/cyboi/state_cyboi_format.c"
 #include "../constant/language/cyboi/state_cyboi_language.c"
 #include "../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../constant/model/cyboi/state/pointer_state_cyboi_model.c"
-#include "../constant/format/cyboi/state_cyboi_format.c"
 #include "../controller/checker.c"
 #include "../executor/communicator/receiver/file/file_receiver.c"
 #include "../executor/memoriser/allocator/part_allocator.c"
@@ -42,7 +42,7 @@
 #include "../logger/logger.c"
 
 /**
- * Initialises the system with an initial signal.
+ * Initialises the system with a startup signal.
  *
  * @param p0 the signal memory item
  * @param p1 the run source item
@@ -50,8 +50,8 @@
  */
 void initialise(void* p0, void* p1, void* p2) {
 
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n\n");
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Initialise system with startup signal.");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Initialise.");
 
     // The startup signal part.
     void* s = *NULL_POINTER_STATE_CYBOI_MODEL;
@@ -63,13 +63,19 @@ void initialise(void* p0, void* p1, void* p2) {
     void* mc = *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Allocate startup signal part.
-    allocate_part((void*) &s, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
+    allocate_part((void*) &s, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
 
-    // Copy startup signal part format.
     // CAUTION! A name is not necessary, since only
     // the actual model and properties are of interest.
-    // CAUTION! The model and properties are received below.
+
+    // Copy startup signal part format.
     overwrite_part_element(s, (void*) PART_ELEMENT_STATE_CYBOI_FORMAT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) FORMAT_PART_STATE_CYBOI_NAME);
+    // Copy startup signal part type.
+    // CAUTION! Assigning the type IS ESSENTIAL for properly
+    // deallocating the part and its child parts at shutdown.
+    overwrite_part_element(s, (void*) PART_ELEMENT_STATE_CYBOI_TYPE, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) TYPE_PART_STATE_CYBOI_NAME);
 
     // Get startup signal part model, properties.
     // CAUTION! Retrieve data ONLY AFTER having called desired functions!
@@ -87,10 +93,27 @@ void initialise(void* p0, void* p1, void* p2) {
     // Receive startup signal model, properties.
     receive_file(sm, sp, md, mc, (void*) PART_ELEMENT_STATE_CYBOI_FORMAT, (void*) CYBOL_TEXT_STATE_CYBOI_LANGUAGE, (void*) UTF_8_CYBOI_ENCODING);
 
-    log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n\n");
+    log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n");
     log_message_terminated((void*) DEBUG_LEVEL_LOG_CYBOI_MODEL, (void*) L"Add startup signal to signal memory.");
 
     // Add part model (signal) to signal memory.
+    //
+    // CAUTION! Use simple POINTER_STATE_CYBOI_TYPE and NOT PART_ELEMENT_STATE_CYBOI_TYPE here.
+    // The signal memory just holds references to knowledge memory parts (signals),
+    // but only the knowledge memory may care about rubbish (garbage) collection.
+    //
+    // Example:
+    // Assume there are two signals in the signal memory.
+    // The second references a logic part that is to be destroyed by the first.
+    // If reference counting from rubbish (garbage) collection were used,
+    // then the logic part serving as second signal could not be deallocated
+    // as long as it is still referenced from the signal memory item.
+    //
+    // But probably, there is a reason the first signal wants to destroy the
+    // second and consequently, the second should not be executed anymore.
+    // After destruction, the second signal just points to null, which is ignored.
+    // Hence, rubbish (garbage) collection would only disturb here
+    // and should be left to the knowledge memory.
     append_item_element(p0, (void*) &s, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME);
 
     // The system is now started up and complete so that a loop
@@ -100,7 +123,7 @@ void initialise(void* p0, void* p1, void* p2) {
     check(p2);
 
     // Deallocate startup signal part.
-    deallocate_part((void*) &s, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
+    deallocate_part((void*) &s);
 }
 
 /* INITIALISER_SOURCE */
