@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -38,10 +38,11 @@
 #include "../controller/manager/internal_memory_manager.c"
 #include "../controller/manager/system_signal_handler_manager.c"
 #include "../controller/initialiser.c"
-#include "../executor/maintainer/shutter/opengl_shutter.c"
-#include "../executor/maintainer/shutter/socket_shutter.c"
-#include "../executor/maintainer/shutter/terminal_shutter.c"
-#include "../executor/maintainer/shutter/x_window_system_shutter.c"
+#include "../executor/maintainer/shutter/opengl/opengl_shutter.c"
+#include "../executor/maintainer/shutter/serial_port/serial_port_shutter.c"
+#include "../executor/maintainer/shutter/socket/socket_shutter.c"
+#include "../executor/maintainer/shutter/terminal/terminal_shutter.c"
+#include "../executor/maintainer/shutter/x_window_system/x_window_system_shutter.c"
 #include "../logger/logger.c"
 #include "../variable/type_size/integral_type_size.c"
 #include "../variable/type_size/real_type_size.c"
@@ -71,8 +72,8 @@
  */
 void manage(void* p0) {
 
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n\n");
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Manage system.");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"\n");
+    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Manage.");
 
     //
     // Variable declaration.
@@ -152,62 +153,82 @@ void manage(void* p0) {
     // away, and the system will detect the change when it occurs.
     //
 
-    // The terminal interrupt request flag.
-    volatile sig_atomic_t terminal_irq_array[1];
-    volatile sig_atomic_t* terminal_irq = terminal_irq_array;
-    // The x window system interrupt request flag.
-    volatile sig_atomic_t x_window_system_irq_array[1];
-    volatile sig_atomic_t* x_window_system_irq = x_window_system_irq_array;
-    // The www service interrupt request flag.
-    volatile sig_atomic_t www_service_irq_array[1];
-    volatile sig_atomic_t* www_service_irq = www_service_irq_array;
     // The cyboi service interrupt request flag.
     volatile sig_atomic_t cyboi_service_irq_array[1];
     volatile sig_atomic_t* cyboi_service_irq = cyboi_service_irq_array;
+    // The serial port interrupt request flag.
+    volatile sig_atomic_t serial_port_irq_array[1];
+    volatile sig_atomic_t* serial_port_irq = serial_port_irq_array;
+    // The terminal interrupt request flag.
+    volatile sig_atomic_t terminal_irq_array[1];
+    volatile sig_atomic_t* terminal_irq = terminal_irq_array;
+    // The www service interrupt request flag.
+    volatile sig_atomic_t www_service_irq_array[1];
+    volatile sig_atomic_t* www_service_irq = www_service_irq_array;
+    // The x window system interrupt request flag.
+    volatile sig_atomic_t x_window_system_irq_array[1];
+    volatile sig_atomic_t* x_window_system_irq = x_window_system_irq_array;
 
-    // The terminal mutex.
-    pthread_mutex_t terminal_mutex_array[1];
-    pthread_mutex_t* terminal_mutex = terminal_mutex_array;
-    // The x window system mutex.
-    pthread_mutex_t x_window_system_mutex_array[1];
-    pthread_mutex_t* x_window_system_mutex = x_window_system_mutex_array;
-    // The www service mutex.
-    pthread_mutex_t www_service_mutex_array[1];
-    pthread_mutex_t* www_service_mutex = www_service_mutex_array;
     // The cyboi service mutex.
     pthread_mutex_t cyboi_service_mutex_array[1];
     pthread_mutex_t* cyboi_service_mutex = cyboi_service_mutex_array;
+    // The serial port mutex.
+    pthread_mutex_t serial_port_mutex_array[1];
+    pthread_mutex_t* serial_port_mutex = serial_port_mutex_array;
+    // The terminal mutex.
+    pthread_mutex_t terminal_mutex_array[1];
+    pthread_mutex_t* terminal_mutex = terminal_mutex_array;
+    // The www service mutex.
+    pthread_mutex_t www_service_mutex_array[1];
+    pthread_mutex_t* www_service_mutex = www_service_mutex_array;
+    // The x window system mutex.
+    pthread_mutex_t x_window_system_mutex_array[1];
+    pthread_mutex_t* x_window_system_mutex = x_window_system_mutex_array;
 
-    // The signal memory sleep time.
-    double signal_memory_sleep_time_array[1];
-    double* signal_memory_sleep_time = signal_memory_sleep_time_array;
-    // The gnu linux console sleep time.
-    double terminal_sleep_time_array[1];
-    double* terminal_sleep_time = terminal_sleep_time_array;
-    // The x window system sleep time.
-    double x_window_system_sleep_time_array[1];
-    double* x_window_system_sleep_time = x_window_system_sleep_time_array;
-    // The www service sleep time.
-    double www_service_sleep_time_array[1];
-    double* www_service_sleep_time = www_service_sleep_time_array;
     // The cyboi service sleep time.
-    double cyboi_service_sleep_time_array[1];
-    double* cyboi_service_sleep_time = cyboi_service_sleep_time_array;
+    int cyboi_service_sleep_time_array[1];
+    int* cyboi_service_sleep_time = cyboi_service_sleep_time_array;
+    // The serial port sleep time.
+    int serial_port_sleep_time_array[1];
+    int* serial_port_sleep_time = serial_port_sleep_time_array;
+    // The signal memory sleep time.
+    int signal_memory_sleep_time_array[1];
+    int* signal_memory_sleep_time = signal_memory_sleep_time_array;
+    // The terminal sleep time.
+    int terminal_sleep_time_array[1];
+    int* terminal_sleep_time = terminal_sleep_time_array;
+    // The www service sleep time.
+    int www_service_sleep_time_array[1];
+    int* www_service_sleep_time = www_service_sleep_time_array;
+    // The x window system sleep time.
+    int x_window_system_sleep_time_array[1];
+    int* x_window_system_sleep_time = x_window_system_sleep_time_array;
 
     //
     // Variable allocation.
     //
 
     // Allocate internal memory data.
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     // CAUTION! The internal memory has a pre-defined count/size,
     // given by the constant INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT.
     allocate_array((void*) &i, (void*) INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT, (void*) POINTER_STATE_CYBOI_TYPE);
     // Allocate knowledge memory part.
-    allocate_part((void*) &k, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
+    allocate_part((void*) &k, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
     // Allocate signal memory item.
-    // CAUTION! The signal memory is given an initial size of 1000,
-    // in order to avoid steady reallocation, for better performance.
-    allocate_item((void*) &s, (void*) NUMBER_1000_INTEGER_STATE_CYBOI_MODEL, (void*) POINTER_STATE_CYBOI_TYPE);
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
+    // CAUTION! It is given an initial size of 1024, in order
+    // to avoid steady reallocation, for better performance.
+    // CAUTION! The signal memory should be a simple array only.
+    // If it was a part, rubbish (garbage) collection would become effective
+    // and manipulate the references count of child parts when removing them,
+    // so that these might get deallocated while still needed.
+    // But only the knowledge memory part has the right to do that.
+    allocate_item((void*) &s, (void*) NUMBER_1024_INTEGER_STATE_CYBOI_MODEL, (void*) POINTER_STATE_CYBOI_TYPE);
 
     //
     // Variable initialisation.
@@ -220,34 +241,21 @@ void manage(void* p0) {
     // the whole runtime knowledge tree as model diagram.
     // Otherwise (empty root type), the printed model diagram would be empty.
 
-    // The knowledge memory part name, format, type item.
-    void* kn = *NULL_POINTER_STATE_CYBOI_MODEL;
-    void* kf = *NULL_POINTER_STATE_CYBOI_MODEL;
-    void* kt = *NULL_POINTER_STATE_CYBOI_MODEL;
+    // Fill knowledge memory.
+    overwrite_part_element(k, (void*) L"root", (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE, (void*) NUMBER_4_INTEGER_STATE_CYBOI_MODEL, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) NAME_PART_STATE_CYBOI_NAME);
+    overwrite_part_element(k, (void*) PART_ELEMENT_STATE_CYBOI_FORMAT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) FORMAT_PART_STATE_CYBOI_NAME);
+    overwrite_part_element(k, (void*) PART_ELEMENT_STATE_CYBOI_TYPE, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) TYPE_PART_STATE_CYBOI_NAME);
 
-    // Get knowledge memory part name, format, type item.
-    // CAUTION! Retrieve data ONLY AFTER having called desired functions!
-    // Inside the structure, arrays may have been reallocated,
-    // with elements pointing to different memory areas now.
-    copy_array_forward((void*) &kn, k, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) NAME_PART_STATE_CYBOI_NAME);
-    copy_array_forward((void*) &kf, k, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) FORMAT_PART_STATE_CYBOI_NAME);
-    copy_array_forward((void*) &kt, k, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TYPE_PART_STATE_CYBOI_NAME);
-
-    // Fill part name item.
-    overwrite_item_element(kn, (void*) L"root", (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE, (void*) NUMBER_4_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-    // Fill part format item.
-    overwrite_item_element(kf, (void*) PART_ELEMENT_STATE_CYBOI_FORMAT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-    // Fill part type item.
-    overwrite_item_element(kt, (void*) PART_ELEMENT_STATE_CYBOI_TYPE, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) TRUE_BOOLEAN_STATE_CYBOI_MODEL, (void*) DATA_ITEM_STATE_CYBOI_NAME);
-
-    // Initialise terminal interrupt request flag.
-    copy_integer((void*) terminal_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
-    // Initialise x window system interrupt request flag.
-    copy_integer((void*) x_window_system_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
-    // Initialise www service interrupt request flag.
-    copy_integer((void*) www_service_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
     // Initialise cyboi service interrupt request flag.
     copy_integer((void*) cyboi_service_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
+    // Initialise serial port interrupt request flag.
+    copy_integer((void*) serial_port_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
+    // Initialise terminal interrupt request flag.
+    copy_integer((void*) terminal_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
+    // Initialise www service interrupt request flag.
+    copy_integer((void*) www_service_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
+    // Initialise x window system interrupt request flag.
+    copy_integer((void*) x_window_system_irq, (void*) FALSE_BOOLEAN_STATE_CYBOI_MODEL);
 
     //
     // In the following mutex initialisation functions, the second parametre
@@ -255,25 +263,29 @@ void manage(void* p0) {
     // If the parametre is null, the mutex is initialised with default attributes.
     //
 
-    // Initialise terminal mutex.
-    pthread_mutex_init(terminal_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
-    // Initialise x window system mutex.
-    pthread_mutex_init(x_window_system_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
-    // Initialise www service mutex.
-    pthread_mutex_init(www_service_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
     // Initialise cyboi service mutex.
     pthread_mutex_init(cyboi_service_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
+    // Initialise serial port mutex.
+    pthread_mutex_init(serial_port_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
+    // Initialise terminal mutex.
+    pthread_mutex_init(terminal_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
+    // Initialise www service mutex.
+    pthread_mutex_init(www_service_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
+    // Initialise x window system mutex.
+    pthread_mutex_init(x_window_system_mutex, *NULL_POINTER_STATE_CYBOI_MODEL);
 
-    // Initialise signal memory sleep time.
-    copy_double((void*) signal_memory_sleep_time, (void*) NUMBER_0_1_DOUBLE_STATE_CYBOI_MODEL);
-    // Initialise gnu linux console sleep time.
-    copy_double((void*) terminal_sleep_time, (void*) NUMBER_0_1_DOUBLE_STATE_CYBOI_MODEL);
-    // Initialise x window system sleep time.
-    copy_double((void*) x_window_system_sleep_time, (void*) NUMBER_0_1_DOUBLE_STATE_CYBOI_MODEL);
-    // Initialise www service sleep time.
-    copy_double((void*) www_service_sleep_time, (void*) NUMBER_0_1_DOUBLE_STATE_CYBOI_MODEL);
     // Initialise cyboi service sleep time.
-    copy_double((void*) cyboi_service_sleep_time, (void*) NUMBER_0_1_DOUBLE_STATE_CYBOI_MODEL);
+    copy_integer((void*) cyboi_service_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
+    // Initialise serial port sleep time.
+    copy_integer((void*) serial_port_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
+    // Initialise signal memory sleep time.
+    copy_integer((void*) signal_memory_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
+    // Initialise terminal sleep time.
+    copy_integer((void*) terminal_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
+    // Initialise www service sleep time.
+    copy_integer((void*) www_service_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
+    // Initialise x window system sleep time.
+    copy_integer((void*) x_window_system_sleep_time, (void*) NUMBER_100000000_INTEGER_STATE_CYBOI_MODEL);
 
     //
     // System startup.
@@ -297,12 +309,12 @@ void manage(void* p0) {
     // Therefore, the knowledge memory and signal memory NEED TO BE ADDED
     // to the internal memory, in order to be forwardable to threads.
 
-    startup_internal_memory(i, (void*) &k, (void*) &s,
-        (void*) &signal_memory_sleep_time,
+    startup_internal_memory(i, (void*) &k, (void*) &s, (void*) &signal_memory_sleep_time,
+        (void*) &cyboi_service_irq, (void*) &cyboi_service_mutex, (void*) &cyboi_service_sleep_time,
+        (void*) &serial_port_irq, (void*) &serial_port_mutex, (void*) &serial_port_sleep_time,
         (void*) &terminal_irq, (void*) &terminal_mutex, (void*) &terminal_sleep_time,
-        (void*) &x_window_system_irq, (void*) &x_window_system_mutex, (void*) &x_window_system_sleep_time,
         (void*) &www_service_irq, (void*) &www_service_mutex, (void*) &www_service_sleep_time,
-        (void*) &cyboi_service_irq, (void*) &cyboi_service_mutex, (void*) &cyboi_service_sleep_time);
+        (void*) &x_window_system_irq, (void*) &x_window_system_mutex, (void*) &x_window_system_sleep_time);
 
     // Start up system signal handler.
     startup_system_signal_handler();
@@ -323,14 +335,16 @@ void manage(void* p0) {
     // corresponding service shutdown operation in cybol logic templates.
     // The "interrupt" procedures are called within the "shutdown" procedures.
 
-    // Shutdown terminal.
-    shutdown_terminal(i, (void*) TERMINAL_THREAD, (void*) TERMINAL_EXIT);
-    // Shutdown x window system.
-    shutdown_x_window_system(i, (void*) X_WINDOW_SYSTEM_THREAD, (void*) X_WINDOW_SYSTEM_EXIT);
-    // Shutdown www service.
-    shutdown_socket(i, (void*) WWW_BASE_INTERNAL_MEMORY_STATE_CYBOI_NAME,(void*) WWW_SERVICE_THREAD, (void*) WWW_SERVICE_EXIT);
     // Shutdown cyboi service.
     shutdown_socket(i, (void*) CYBOI_BASE_INTERNAL_MEMORY_STATE_CYBOI_NAME, (void*) CYBOI_SERVICE_THREAD, (void*) CYBOI_SERVICE_EXIT);
+    // Shutdown serial port.
+    shutdown_serial_port(i, (void*) SERIAL_PORT_THREAD, (void*) SERIAL_PORT_EXIT);
+    // Shutdown terminal.
+    shutdown_terminal(i, (void*) TERMINAL_THREAD, (void*) TERMINAL_EXIT);
+    // Shutdown www service.
+    shutdown_socket(i, (void*) WWW_BASE_INTERNAL_MEMORY_STATE_CYBOI_NAME,(void*) WWW_SERVICE_THREAD, (void*) WWW_SERVICE_EXIT);
+    // Shutdown x window system.
+    shutdown_x_window_system(i, (void*) X_WINDOW_SYSTEM_THREAD, (void*) X_WINDOW_SYSTEM_EXIT);
 
     //
     // Variable finalisation.
@@ -342,25 +356,32 @@ void manage(void* p0) {
     // thus make all entries invalid, since they could not be found
     // at their original index anymore.
 
-    // Destroy terminal mutex.
-    pthread_mutex_destroy(terminal_mutex);
-    // Destroy x window system mutex.
-    pthread_mutex_destroy(x_window_system_mutex);
-    // Destroy www service mutex.
-    pthread_mutex_destroy(www_service_mutex);
     // Destroy cyboi service mutex.
     pthread_mutex_destroy(cyboi_service_mutex);
+    // Destroy serial port mutex.
+    pthread_mutex_destroy(serial_port_mutex);
+    // Destroy terminal mutex.
+    pthread_mutex_destroy(terminal_mutex);
+    // Destroy www service mutex.
+    pthread_mutex_destroy(www_service_mutex);
+    // Destroy x window system mutex.
+    pthread_mutex_destroy(x_window_system_mutex);
 
     //
     // Variable deallocation.
     //
 
     // Deallocate signal memory item.
-    deallocate_item((void*) &s, (void*) NUMBER_1000_INTEGER_STATE_CYBOI_MODEL, (void*) POINTER_STATE_CYBOI_TYPE);
+    deallocate_item((void*) &s, (void*) POINTER_STATE_CYBOI_TYPE);
     // Deallocate knowledge memory part.
-    deallocate_part((void*) &k, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
+    // CAUTION! This is the knowledge memory tree root node.
+    // It has to be deallocated MANUALLY here.
+    // Its references count was initially zero and never
+    // got changed during programme execution,
+    // so that this root part is not deallocated automatically.
+    deallocate_part((void*) &k);
     // Deallocate internal memory data.
-    deallocate_array((void*) &i, (void*) INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT, (void*) POINTER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &i, (void*) INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT, (void*) INTERNAL_MEMORY_STATE_CYBOI_MODEL_COUNT, (void*) POINTER_STATE_CYBOI_TYPE);
 }
 
 /* MANAGER_SOURCE */
