@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -31,13 +31,16 @@
 #include <fcntl.h>
 //?? TEST END
 
+/*??
 #include <netinet/in.h>
 #include <sys/socket.h>
+*/
 
-#include "../../../../constant/model/cybol/communication_mode_cybol_model.c"
+#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
 #include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
+#include "../../../../constant/model/cybol/communication_mode_cybol_model.c"
 #include "../../../../constant/type/cyboi/state_cyboi_type.c"
 #include "../../../../executor/communicator/sender/datagram_socket_sender.c"
 #include "../../../../executor/communicator/sender/raw_socket_sender.c"
@@ -292,11 +295,15 @@ void apply_send_socket_allocate_host_address(void* p0, void* p1) {
             if (*n == AF_INET) {
 
                 // Allocate ipv4 socket address.
+                // CAUTION! Due to memory allocation handling, the size MUST NOT
+                // be negative or zero, but have at least a value of ONE.
                 *a = malloc(*INTERNET_PROTOCOL_4_HOST_ADDRESS_SOCKET_TYPE_SIZE);
 
             } else if (*n == AF_INET6) {
 
                 // Allocate ipv6 socket address.
+                // CAUTION! Due to memory allocation handling, the size MUST NOT
+                // be negative or zero, but have at least a value of ONE.
                 *a = malloc(*INTERNET_PROTOCOL_6_HOST_ADDRESS_SOCKET_TYPE_SIZE);
             }
 
@@ -357,6 +364,8 @@ void apply_send_socket_allocate_socket_address(void* p0, void* p1, void* p2) {
                     *as = *SIGNED_SHORT_INTEGER_INTEGRAL_TYPE_SIZE + *NUMBER_108_INTEGER_STATE_CYBOI_MODEL;
 
                     // Allocate socket address.
+                    // CAUTION! Due to memory allocation handling, the size MUST NOT
+                    // be negative or zero, but have at least a value of ONE.
                     *a = malloc(*as);
 
                 } else if (*n == AF_INET) {
@@ -365,6 +374,8 @@ void apply_send_socket_allocate_socket_address(void* p0, void* p1, void* p2) {
                     *as = *INTERNET_PROTOCOL_4_SOCKET_ADDRESS_SOCKET_TYPE_SIZE;
 
                     // Allocate ipv4 socket address.
+                    // CAUTION! Due to memory allocation handling, the size MUST NOT
+                    // be negative or zero, but have at least a value of ONE.
                     *a = malloc(*as);
 
                 } else if (*n == AF_INET6) {
@@ -373,6 +384,8 @@ void apply_send_socket_allocate_socket_address(void* p0, void* p1, void* p2) {
                     *as = *INTERNET_PROTOCOL_6_SOCKET_ADDRESS_SOCKET_TYPE_SIZE;
 
                     // Allocate ipv6 socket address.
+                    // CAUTION! Due to memory allocation handling, the size MUST NOT
+                    // be negative or zero, but have at least a value of ONE.
                     *a = malloc(*as);
                 }
 
