@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -28,6 +28,7 @@
 
 #ifdef GNU_LINUX_OPERATING_SYSTEM
 
+/*??
 #include <arpa/inet.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -36,20 +37,25 @@
 #include <fcntl.h>
 #include <stdio.h>
 #include <unistd.h>
+*/
 
 #include "../../../../constant/model/character_code/unicode/unicode_character_code_model.c"
-#include "../../../../constant/model/cybol/address_cybol_model.c"
-#include "../../../../constant/model/cybol/communication_style_cybol_model.c"
-#include "../../../../constant/model/cybol/http_request_cybol_model.c"
-#include "../../../../constant/model/cybol/namespace_cybol_model.c"
+#include "../../../../constant/model/cyboi/log/level_log_cyboi_model.c"
+#include "../../../../constant/model/cyboi/log/message_log_cyboi_model.c"
+#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
+#include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
+//?? #include "../../../../constant/model/cybol/address_cybol_model.c"
+//?? #include "../../../../constant/model/cybol/communication_style_cybol_model.c"
+//?? #include "../../../../constant/model/cybol/http_request_cybol_model.c"
+//?? #include "../../../../constant/model/cybol/namespace_cybol_model.c"
 #include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"
 #include "../../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
 #include "../../../../constant/name/cyboi/state/internal_memory_state_cyboi_name.c"
 #include "../../../../constant/type/cyboi/state_cyboi_type.c"
-#include "../../../../executor/accessor/getter.c"
 #include "../../../../executor/modifier/overwriter/array_overwriter.c"
 #include "../../../../executor/comparator/all/array_all_comparator.c"
-#include "../../../../executor/memoriser/allocator.c"
+//?? #include "../../../../executor/memoriser/allocator.c"
+#include "../../../../logger/logger.c"
 #include "../../../../variable/type_size/socket_type_size.c"
 
 /**
@@ -133,12 +139,20 @@ void startup_socket(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
         }
 
         // Allocate socket address size of this system.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         allocate((void*) &as, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
         // Allocate communication partner socket address size.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         allocate((void*) &pas, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
         // Allocate socket of this system.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         allocate((void*) &s, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
         // Allocate communication partner socket.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         allocate((void*) &ps, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 
         // Initialise socket address size of this system.
@@ -182,6 +196,8 @@ void startup_socket(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
 
         // Allocate socket address of this system.
         // Allocate communication partner socket address.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         if (an == AF_LOCAL) {
 
             la = (struct sockaddr_un*) malloc(*as);
@@ -215,6 +231,8 @@ void startup_socket(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
         }
 
         // Allocate character buffer count and size.
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         allocate((void*) &bc, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
         allocate((void*) &bs, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 
@@ -223,10 +241,11 @@ void startup_socket(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
         // suffice for transferring standard data over tcp/ip.
         // Another possible size could be 8192.
         copy_integer(bc, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL);
-        copy_integer(bs, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL);
+        copy_integer(bs, (void*) NUMBER_2048_INTEGER_STATE_CYBOI_MODEL);
 
         // Allocate character buffer.
-        //
+        // CAUTION! Due to memory allocation handling, the size MUST NOT
+        // be negative or zero, but have at least a value of ONE.
         // CAUTION! Allocate character buffer only AFTER
         // the buffer size has been initialised above!
         allocate((void*) &b, (void*) bs, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
