@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -184,6 +184,8 @@ void test_wide_character_output() {
     struct termios* tw = (struct termios*) *NULL_POINTER_STATE_CYBOI_MODEL;
 
     // Create terminal internals.
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
 //??        allocate((void*) &t, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE, (void*) INTEGER_NUMBER_STATE_PRIMITIVE_STATE_CYBOI_MODEL_COUNT);
     to = (struct termios*) malloc(sizeof(struct termios));
     tw = (struct termios*) malloc(sizeof(struct termios));
@@ -204,12 +206,17 @@ void test_wide_character_output() {
     // Set termios attributes.
     tcsetattr(d, TCSANOW, (void*) tw);
 
+    free(to);
+    free(tw);
+
     // The terminated control sequences string.
     void* ts = *NULL_POINTER_STATE_CYBOI_MODEL;
     int tsc = *NUMBER_0_INTEGER_STATE_CYBOI_MODEL;
     int tss = *NUMBER_1000_INTEGER_STATE_CYBOI_MODEL;
 
-    // Create terminated control sequences string.
+    // Allocate terminated control sequences string.
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     allocate_array((void*) &ts, (void*) &tss, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
     // Set terminated control sequences string by first copying the actual
@@ -256,7 +263,7 @@ void test_wide_character_output() {
 //??    log_write((void*) stdout, (wchar_t*) ts, t);
 
     // Destroy terminated control sequences.
-    deallocate_array((void*) &ts, (void*) &tss, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &ts, (void*) &tsc, (void*) &tss, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
     // UTF-8 still allows you to use C1 control characters such as CSI, even
     // though UTF-8 also uses bytes in the range 0x80-0x9F. It is important to
@@ -320,7 +327,9 @@ void test_communicator_file_read() {
     // The file name count.
     int fnc = *NUMBER_26_INTEGER_STATE_CYBOI_MODEL;
 
-    allocate_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
+    allocate_array((void*) &a, (void*) &as, (void*) &CHARACTER_ARRAY);
 //??    receive_file((void*) &a, (void*) &as, (void*) &ac, (void*) &fn, (void*) &fnc);
 
     fwprintf(stdout, L"a: %i\n", a);
@@ -346,7 +355,7 @@ void test_communicator_file_read() {
         j++;
     }
 
-    deallocate_array((void*) &a, (void*) &CHARACTER_ARRAY, (void*) &as);
+    deallocate_array((void*) &a, (void*) &ac, (void*) &as, (void*) &CHARACTER_ARRAY);
 */
 }
 
@@ -443,6 +452,9 @@ void test_communicator_console_input() {
         // Reset terminal to old settings.
         tcsetattr(d, TCSANOW, (void*) to);
 
+        free(to);
+        free(tn);
+
     } else {
 
         if (errno == EBADF) {
@@ -621,12 +633,12 @@ void test_communicator_mesa_opengl() {
 /**
  * Tests the communicator.
  *
- * Sub test procedure call can be activated/ deactivated here
+ * Sub test procedure calls can be activated/ deactivated here
  * by simply commenting/ uncommenting the corresponding lines.
  */
 void test_communicator() {
 
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test communicator.");
+//    fwprintf(stdout, L"TEST communicator.\n");
 
 //    test_stdout_stdout();
 //    test_wide_character_wprintf();
