@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2012. Christian Heller.
+ * Copyright (C) 1999-2013. Christian Heller.
  *
  * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
  *
@@ -19,7 +19,7 @@
  * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
  * Christian Heller <christian.heller@tuxtax.de>
  *
- * @version CYBOP 0.12.0 2012-08-22
+ * @version CYBOP 0.13.0 2013-03-29
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -122,7 +122,7 @@ void test_pointer_return() {
     fwprintf(stdout, L"r: %ls\n", (wchar_t*) r);
 
     // Destroy character array.
-    deallocate_array((void*) &cs, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &cs, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -162,8 +162,8 @@ void test_character_array_single_element() {
     overwrite_array(c, (void*) LATIN_CAPITAL_LETTER_A_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_0_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
     overwrite_array(c, (void*) LATIN_CAPITAL_LETTER_B_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_1_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
     overwrite_array(c, (void*) LATIN_CAPITAL_LETTER_C_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_2_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
-    overwrite_array(c, (void*) LINE_FEED_CONTROL_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_3_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
-    overwrite_array(c, (void*) NULL_CONTROL_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_4_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    overwrite_array(c, (void*) LINE_FEED_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_3_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    overwrite_array(c, (void*) NULL_UNICODE_CHARACTER_CODE_MODEL, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) NUMBER_4_INTEGER_STATE_CYBOI_MODEL, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 */
 
     // Print out array contents.
@@ -186,7 +186,7 @@ void test_character_array_single_element() {
     }
 
     // Destroy character array.
-    deallocate_array((void*) &c, (void*) &cs, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &c, (void*) &cs, (void*) &cs, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -235,6 +235,8 @@ void test_character_array_multiple_elements() {
     // including two places for new line '\n' and c string termination '\0'.
     int ns = *NUMBER_15_INTEGER_STATE_CYBOI_MODEL;
 
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     reallocate_array((void*) &d, (void*) &ns, (void*) &ns, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 
     log_write((void*) stdout, (wchar_t*) d);
@@ -248,7 +250,7 @@ void test_character_array_multiple_elements() {
     log_write((void*) stdout, (wchar_t*) r);
 
     // Destroy destination array.
-    deallocate_array((void*) &d, (void*) &ns, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &d, (void*) &ns, (void*) &ns, (void*) WIDE_CHARACTER_TEXT_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -316,9 +318,9 @@ void test_integer_array() {
     fwprintf(stdout, L"post result2: %i\n", *result2);
 
     // Deallocate test knowledge model.
-    deallocate_array((void*) &m, (void*) ms, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
-    deallocate_array((void*) &mc, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
-    deallocate_array((void*) &ms, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &m, (void*) mc, (void*) ms, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &mc, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &ms, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) INTEGER_NUMBER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -340,6 +342,8 @@ void test_pointer_array() {
 
     // The pointer array.
     void** p = NULL_POINTER_STATE_CYBOI_MODEL;
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     int ps = *NUMBER_1_INTEGER_STATE_CYBOI_MODEL;
 
     // Create pointer array.
@@ -376,7 +380,7 @@ void test_pointer_array() {
     //
 
     // Destroy pointer array.
-    deallocate_array((void*) &p, (void*) &ps, (void*) POINTER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &p, (void*) &ps, (void*) &ps, (void*) POINTER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -388,6 +392,8 @@ void test_pointer_array_with_null_values() {
 
     // The pointer array.
     void* a = *NULL_POINTER_STATE_CYBOI_MODEL;
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     int as = *NUMBER_5_INTEGER_STATE_CYBOI_MODEL;
 
     allocate_array((void*) &a, (void*) &as, (void*) POINTER_STATE_CYBOI_TYPE);
@@ -424,7 +430,7 @@ void test_pointer_array_with_null_values() {
     fwprintf(stdout, L"NULL_POINTER_STATE_CYBOI_MODEL: %i \n", NULL_POINTER_STATE_CYBOI_MODEL);
     fwprintf(stdout, L"*NULL_POINTER_STATE_CYBOI_MODEL: %i \n", *NULL_POINTER_STATE_CYBOI_MODEL);
 
-    deallocate_array((void*) &a, (void*) &as, (void*) POINTER_STATE_CYBOI_TYPE);
+    deallocate_array((void*) &a, (void*) &as, (void*) &as, (void*) POINTER_STATE_CYBOI_TYPE);
 }
 
 /**
@@ -449,6 +455,8 @@ void test_pointer_addition() {
     log_write((void*) stdout, L"Test pointer addition:\n");
 
     // Allocate arrays of an arbitrary size.
+    // CAUTION! Due to memory allocation handling, the size MUST NOT
+    // be negative or zero, but have at least a value of ONE.
     void* v = (void*) malloc(*NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
     int* i = (int*) malloc(*NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
     double* d = (double*) malloc(*NUMBER_10_INTEGER_STATE_CYBOI_MODEL);
@@ -582,12 +590,12 @@ void test_pointer_addition() {
 /**
  * Tests the pointer handling.
  *
- * Sub test procedure call can be activated/ deactivated here
+ * Sub test procedure calls can be activated/ deactivated here
  * by simply commenting/ uncommenting the corresponding lines.
  */
 void test_pointer() {
 
-    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Test pointer handling.");
+//    fwprintf(stdout, L"TEST pointer.\n");
 
 //    test_pointer_null();
 //    test_pointer_cast();
